# ibsec

## Installation and usage

### Installation

`pip install ibsec`

### Configuration

Create a file in your home directory named `.ibsec_codes.json` which will contain the data from your security card. See [ibsec_codes.json.example](ibsec_codes.json.example) for an example.

### Usage

`ibsec [code1] [code2]`

Your code will be copied to your clipboard.
